---
title: <span class="badge object-type-scalar"></span> MegaWatt
---
# <span class="badge object-type-scalar"></span> MegaWatt

Energy: Megawatt (MW)

## Definition

```python
# Energy: Megawatt (MW)
MegaWatt: typing.Literal["megwatt"] = "megwatt"
```
